{% load static %}
<script type="text/javascript" src="{% static 'geonode-client/js/viewer.min.js' %}"></script>
<script type="text/javascript" src="{% static 'geonode-client/cesium/Cesium.js' %}"></script>
